import re

class mitre_rules():
    def __init__(self):
        self.oid = []
        self.tactic = 'Defense Evasion'
        self.tid = 'T1500'
        self.name = 'Compile After Delivery'
        self.description = '''Delivers files to victims as uncompiled code which will need to be compiled before execution.'''
        
    def run_rules(self, bundles):
        cnt = 0
        for entry in bundles['objects']:
            if entry['type'] == 'indicator':
                if re.search('process:command_line .*[\"\']\%Windows\%\\\\Microsoft\.NET\\\\Framework\\\\.+\\\\csc(\.exe)?', entry['pattern'], re.IGNORECASE):
                    self.oid.append(entry['id'])
                    cnt += 1
                    break
        if cnt != 0:
            return self
        else:
            return False